@@ -1,5 +1,5 @@
 package MsOffice::Word::Surgeon::Run;
-use feature 'state';
+use 5.24.0;
 use Moose;
 use MooseX::StrictConstructor;
 use MsOffice::Word::Surgeon::Utils qw(maybe_preserve_spaces is_at_run_level);
@@ -7,20 +7,29 @@ use Carp                           qw(croak);
 
 use namespace::clean -except => 'meta';
 
+our $VERSION = '2.0';
+
+#======================================================================
+# ATTRIBUTES
+#======================================================================
+
 has 'xml_before'  => (is => 'ro', isa => 'Str', required => 1);
 has 'props'       => (is => 'ro', isa => 'Str', required => 1);
 has 'inner_texts' => (is => 'ro', required => 1,
                       isa => 'ArrayRef[MsOffice::Word::Surgeon::Text]');
 
-our $VERSION = '1.08';
+#======================================================================
+# METHODS
+#======================================================================
+
 
 sub as_xml {
   my $self = shift;
   my $xml  = $self->xml_before;
-  if (@{$self->inner_texts}) {
+  if ($self->inner_texts->@*) {
     $xml .= "<w:r>";
     $xml .= "<w:rPr>" . $self->props . "</w:rPr>" if $self->props;
-    $xml .= $_->as_xml foreach @{$self->inner_texts};
+    $xml .= $_->as_xml foreach $self->inner_texts->@*;
     $xml .= "</w:r>";
   }
 
@@ -43,14 +52,14 @@ sub merge {
            . $next_run->xml_before;
 
   # loop over all text nodes of the next run
-  foreach my $txt (@{$next_run->inner_texts}) {
-    if (@{$self->{inner_texts}} && !$txt->xml_before) {
+  foreach my $txt ($next_run->inner_texts->@*) {
+    if ($self->{inner_texts}->@* && !$txt->xml_before) {
       # concatenate current literal text with the previous text node
       $self->{inner_texts}[-1]->merge($txt);
     }
     else {
       # cannot merge, just add to the list of inner text nodes
-      push @{$self->{inner_texts}}, $txt;
+      push $self->{inner_texts}->@*, $txt;
     }
   }
 }
@@ -59,14 +68,14 @@ sub merge {
 sub replace {
   my ($self, $pattern, $replacement_callback, %replacement_args) = @_;
 
-  my $xml = $self->xml_before;
-
+  # apply replacement to inner texts
   $replacement_args{run} = $self;
-
   my @inner_xmls
     = map {$_->replace($pattern, $replacement_callback, %replacement_args)}
-          @{$self->inner_texts};
+          $self->inner_texts->@*;
 
+  # a machinery of closures for assembling the new xml
+  my $xml = $self->xml_before;
   my $is_run_open;
   my $maybe_open_run  = sub {if (!$is_run_open) {
                               $xml .= "<w:r>";
@@ -78,24 +87,20 @@ sub replace {
                               $is_run_open = undef;
                             }};
 
+  # apply the machinery, loop over inner texts
   foreach my $inner_xml (@inner_xmls) {
-    if (is_at_run_level($inner_xml)) {
-      $maybe_close_run->();
-      $xml .= $inner_xml;
-    }
-    else {
-      $maybe_open_run->();
-      $xml .= $inner_xml;
-    }
+    is_at_run_level($inner_xml) ? $maybe_close_run->() : $maybe_open_run->();
+    $xml .= $inner_xml;
   }
 
+  # final cleanup
   $maybe_close_run->();
+
   return $xml;
 }
 
 
 
-
 sub remove_caps_property {
   my $self = shift;
 
@@ -194,3 +199,15 @@ L<MsOffice::Word::Surgeon/replace>.
 Searches in the run properties for a C<< <w:caps/> >> property;
 if found, removes it, and replaces all inner texts by their
 uppercase equivalents.
+
+
+=head1 AUTHOR
+
+Laurent Dami, E<lt>dami AT cpan DOT org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2019-2022 by Laurent Dami.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
