@@ -1,5 +1,5 @@
 package MsOffice::Word::Surgeon::Text;
-use feature 'state';
+use 5.24.0;
 use Moose;
 use MooseX::StrictConstructor;
 use MsOffice::Word::Surgeon::Utils qw(maybe_preserve_spaces is_at_run_level);
@@ -7,10 +7,19 @@ use Carp                           qw(croak);
 
 use namespace::clean -except => 'meta';
 
+
+our $VERSION = '2.0';
+
+#======================================================================
+# ATTRIBUTES
+#======================================================================
+
 has 'xml_before'   => (is => 'ro', isa => 'Str');
 has 'literal_text' => (is => 'ro', isa => 'Str', required => 1);
 
-our $VERSION = '1.08';
+#======================================================================
+# METHODS
+#======================================================================
 
 
 sub as_xml {
@@ -126,9 +135,9 @@ sub replace {
   # handle remaining contents after the last match
   if ($txt_after_last_match) {
     $add_to_current_text_node->($txt_after_last_match);
-    $maybe_clear_current_text_node->();
   }
-  elsif ($xml_before) {
+  $maybe_clear_current_text_node->();
+  if ($xml_before) {
     !$xml or croak "internal error : Text::xml_before was ignored during replacements";
     $xml = $xml_before;
   }
@@ -236,3 +245,15 @@ L<MsOffice::Word::Surgeon/replace>.
 
 Puts the literal text within the node into uppercase letters.
 
+
+=head1 AUTHOR
+
+Laurent Dami, E<lt>dami AT cpan DOT org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2019-2022 by Laurent Dami.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
