@@ -1,9 +1,11 @@
 package MsOffice::Word::Surgeon::Utils;
+use strict;
+use warnings;
 
 use Exporter  qw/import/;
 our @EXPORT = qw/maybe_preserve_spaces is_at_run_level/;
 
-our $VERSION = '1.08';
+our $VERSION = '2.0';
 
 sub maybe_preserve_spaces {
   my ($txt) = @_;
@@ -16,7 +18,6 @@ sub is_at_run_level {
 }
 
 
-
 1;
 
 __END__
